@@ -23,11 +23,11 @@ RTPG - is a module for accessing to rtorrent's SCGI functions.
 
 =head1 VERSION
 
-0.1.0
+0.3
 
 =cut
 
-our $VERSION=0.1;
+our $VERSION=0.3;
 
 =head1 SYNOPSIS
 
@@ -352,6 +352,30 @@ sub file_list
     return $list;
 }
 
+=head2 set_files_priorities(tid, pri)
+
+This method updates priorities of all files in one torrent
+
+=head3 EXAMPLE
+ 
+ # standard version
+ my $error=$h->set_files_priorities($tid, $pri);
+ my ($error)=$h->set_files_priorities($tid, $pri);
+
+ # died version
+ $h->set_files_priorities($tid, $pri);
+
+=cut
+sub set_files_priorities
+{
+    my ($self, $id, $pri)=@_;
+    my ($list, $error) =
+        $self->rpc_command('f.multicall', $id, '', "f.set_priority=$pri");
+    return $error if defined wantarray;
+    die $error if $error;
+    return undef;
+}
+
 =head2 system_information
 
 The method returns the link to hash about system information. The hash
@@ -533,8 +557,9 @@ sub _normalize_one_torrent_info($)
 
 =head1 AUTHORS
 
- Copyright (C) 2008 Dmitry E. Oboukhov <unera@debian.org>
- Copyright (C) 2008 Nikolaev Roman <rshadow@rambler.ru>
+Copyright (C) 2008 Dmitry E. Oboukhov <unera@debian.org>,
+
+Copyright (C) 2008 Nikolaev Roman <rshadow@rambler.ru>
 
 =head1 LICENSE
 
